@@ -25,11 +25,9 @@ sub new {
 	my ($class, $sob, $spec, $name) = @_;
 	my ($self);
 	
-	$class = shift;
-	
 	$self = {sob => $sob};
 
-	bless $self;
+	bless $self, $class;
 	
 	return $self;
 }
@@ -138,7 +136,7 @@ Stefan Hornburg (Racke), <racke@linuxia.de>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2014 Stefan Hornburg (Racke) <racke@linuxia.de>.
+Copyright 2010-2015 Stefan Hornburg (Racke) <racke@linuxia.de>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
