@@ -47,7 +47,7 @@ sub new {
 	$self = {%args, containers => {}, lists => {}, pagings => {}, forms => {},
 			 params => {}, values => {}, query => {}, file => undef};
 	
-	bless $self;
+	bless $self, $class;
 }
 
 =head1 METHODS
@@ -108,7 +108,7 @@ sub list {
 }
 
 =head2 forms
-	
+
 Returns list of L<Template::Flute::Form> objects for this template.
 
 =cut
@@ -919,7 +919,7 @@ Stefan Hornburg (Racke), <racke@linuxia.de>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2014 Stefan Hornburg (Racke) <racke@linuxia.de>.
+Copyright 2010-2015 Stefan Hornburg (Racke) <racke@linuxia.de>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
